@@ -500,7 +500,7 @@ class DockerWorker(object):
         current_dimensions = container_info['HostConfig']
         for key1, key2 in dimension_map.items():
             # NOTE(mgoddard): If a resource has been explicitly requested,
-            # check for a match. Otherwise, ensure is is set to the default.
+            # check for a match. Otherwise, ensure it is set to the default.
             if key1 in new_dimensions:
                 if key1 == 'ulimits':
                     if self.compare_ulimits(new_dimensions[key1],
@@ -624,8 +624,8 @@ class DockerWorker(object):
 
             split_vol = vol.split(':')
 
-            if (len(split_vol) == 2
-               and ('/' not in split_vol[0] or '/' in split_vol[1])):
+            if (len(split_vol) == 2 and
+               ('/' not in split_vol[0] or '/' in split_vol[1])):
                 split_vol.append('rw')
 
             vol_list.append(split_vol[1])
@@ -833,10 +833,8 @@ class DockerWorker(object):
             graceful_timeout = 10
         container = self.check_container()
         if not container:
-            ignore_missing = self.params.get('ignore_missing')
-            if not ignore_missing:
-                self.module.fail_json(
-                    msg="No such container: {} to stop".format(name))
+            self.module.fail_json(
+                msg="No such container: {} to stop".format(name))
         elif not container['Status'].startswith('Exited '):
             self.changed = True
             self.dc.stop(name, timeout=graceful_timeout)
@@ -967,7 +965,6 @@ def generate_module():
         dimensions=dict(required=False, type='dict', default=dict()),
         tty=dict(required=False, type='bool', default=False),
         client_timeout=dict(required=False, type='int', default=120),
-        ignore_missing=dict(required=False, type='bool', default=False),
     )
     required_if = [
         ['action', 'pull_image', ['image']],
